@@ -1,4 +1,5 @@
 use crate::core::prelude::*;
+use crate::dff_setup;
 use crate::widgets::dff::DFF;
 
 // Adopted from Alchitry.com Lucid module `pn_gen`
@@ -8,16 +9,12 @@ pub struct LFSRSimple {
     pub clock: Signal<In, Clock>,
     pub strobe: Signal<In, Bit>,
     pub num: Signal<Out, Bits<32>>,
-    pub reset: Signal<In, Bit>,
+    pub reset: Signal<In, Reset>,
     x: DFF<Bits<32>>,
     y: DFF<Bits<32>>,
     z: DFF<Bits<32>>,
     w: DFF<Bits<32>>,
     t: Signal<Local, Bits<32>>,
-    x_init: Constant<Bits<32>>,
-    y_init: Constant<Bits<32>>,
-    z_init: Constant<Bits<32>>,
-    w_init: Constant<Bits<32>>,
 }
 
 const SEED: u128 = 0x843233523a613966423b622562592c62;
@@ -29,15 +26,11 @@ impl Default for LFSRSimple {
             strobe: Default::default(),
             num: Default::default(),
             reset: Default::default(),
-            x: Default::default(),
-            y: Default::default(),
-            z: Default::default(),
-            w: Default::default(),
+            x: DFF::new_with_reset_val((SEED & 0xFFFF_FFFF_u128).into()),
+            y: DFF::new_with_reset_val(((SEED >> 32) & 0xFFFF_FFFF_u128).into()),
+            z: DFF::new_with_reset_val(((SEED >> 64) & 0xFFFF_FFFF_u128).into()),
+            w: DFF::new_with_reset_val(((SEED >> 96) & 0xFFFF_FFFF_u128).into()),
             t: Default::default(),
-            x_init: Constant::new((SEED & 0xFFFF_FFFF_u128).into()),
-            y_init: Constant::new(((SEED >> 32) & 0xFFFF_FFFF_u128).into()),
-            z_init: Constant::new(((SEED >> 64) & 0xFFFF_FFFF_u128).into()),
-            w_init: Constant::new(((SEED >> 96) & 0xFFFF_FFFF_u128).into()),
         }
     }
 }
@@ -45,16 +38,9 @@ impl Default for LFSRSimple {
 impl Logic for LFSRSimple {
     #[hdl_gen]
     fn update(&mut self) {
-        self.x.clk.next = self.clock.val();
-        self.y.clk.next = self.clock.val();
-        self.z.clk.next = self.clock.val();
-        self.w.clk.next = self.clock.val();
+        dff_setup!(self, clock, reset, x, y, z, w);
         self.num.next = self.w.q.val();
         self.t.next = self.x.q.val() ^ (self.x.q.val() << 11_usize);
-        self.x.d.next = self.x.q.val();
-        self.y.d.next = self.y.q.val();
-        self.w.d.next = self.w.q.val();
-        self.z.d.next = self.z.q.val();
         if self.strobe.val() {
             self.x.d.next = self.y.q.val();
             self.y.d.next = self.z.q.val();
@@ -64,12 +50,6 @@ impl Logic for LFSRSimple {
                 ^ self.t.val()
                 ^ (self.t.val() >> 8_usize);
         }
-        if self.reset.val() {
-            self.x.d.next = self.x_init.val();
-            self.y.d.next = self.y_init.val();
-            self.z.d.next = self.z_init.val();
-            self.w.d.next = self.w_init.val();
-        }
     }
 }
 
