@@ -1,6 +1,7 @@
 use rust_hdl::core::prelude::*;
 use rust_hdl::widgets::prelude::*;
 use std::time::Duration;
+use rust_hdl::bsp::alchitry_cu::pins::clock;
 
 pub const MHZ100: u64 = 100_000_000;
 
@@ -8,14 +9,18 @@ pub const MHZ100: u64 = 100_000_000;
 pub struct AlchitryCuPulser {
     pulser: Pulser,
     clock: Signal<In, Clock>,
+    reset: Signal<Local, Reset>,
     leds: Signal<Out, Bits<8>>,
+    auto_reset: AutoReset,
 }
 
 impl Logic for AlchitryCuPulser {
     #[hdl_gen]
     fn update(&mut self) {
         self.pulser.enable.next = true;
-        self.pulser.clock.next = self.clock.val();
+        self.auto_reset.clock.next = self.clock.val();
+        self.reset.next = self.auto_reset.reset.val();
+        clock_reset!(self, clock, reset, pulser);
         self.leds.next = 0x00_u32.into();
         if self.pulser.pulse.val() {
             self.leds.next = 0xAA_u32.into();
@@ -33,7 +38,9 @@ impl Default for AlchitryCuPulser {
         Self {
             pulser,
             clock: rust_hdl::bsp::alchitry_cu::pins::clock(),
+            reset: Default::default(),
             leds: rust_hdl::bsp::alchitry_cu::pins::leds(),
+            auto_reset: Default::default()
         }
     }
 }
