@@ -4,7 +4,9 @@ use rust_hdl::widgets::prelude::*;
 
 #[derive(LogicBlock, Default)]
 struct SyncVecTest {
+    pub reset1: Signal<In, Reset>,
     pub clock1: Signal<In, Clock>,
+    pub reset2: Signal<In, Reset>,
     pub clock2: Signal<In, Clock>,
     pub sender: SyncSender<Bits<8>>,
     pub recv: SyncReceiver<Bits<8>>,
@@ -13,8 +15,8 @@ struct SyncVecTest {
 impl Logic for SyncVecTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.sender.clock.next = self.clock1.val();
-        self.recv.clock.next = self.clock2.val();
+        clock_reset!(self, clock1, reset1, sender);
+        clock_reset!(self, clock2, reset2, recv);
         self.sender.ack_in.next = self.recv.ack_out.val();
         self.recv.flag_in.next = self.sender.flag_out.val();
         self.recv.sig_cross.next = self.sender.sig_cross.val();
@@ -25,8 +27,10 @@ impl Logic for SyncVecTest {
 fn test_sync_vec() {
     let mut uut = SyncVecTest::default();
     uut.clock1.connect();
+    uut.reset1.connect();
     uut.sender.sig_in.connect();
     uut.clock2.connect();
+    uut.reset2.connect();
     uut.sender.send.connect();
     uut.connect_all();
     yosys_validate("sync", &generate_verilog(&uut)).unwrap();
@@ -39,6 +43,7 @@ fn test_sync_vec() {
     });
     sim.add_testbench(move |mut sim: Sim<SyncVecTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock1, reset1, x);
         wait_clock_true!(sim, clock1, x);
         for i in 0..150 {
             x.sender.sig_in.next = (i as u32).into();
@@ -52,6 +57,7 @@ fn test_sync_vec() {
     });
     sim.add_testbench(move |mut sim: Sim<SyncVecTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock2, reset2, x);
         wait_clock_true!(sim, clock2, x);
         for i in 0_u32..150_u32 {
             x = sim.watch(|x| x.recv.update.val(), x)?;
@@ -74,7 +80,9 @@ fn test_vector_synchronizer() {
     top_wrap!(VectorSynchronizer<Bits<8>>, TestCircuit);
     let mut dev: TestCircuit = Default::default();
     dev.uut.clock_in.connect();
+    dev.uut.reset_in.connect();
     dev.uut.clock_out.connect();
+    dev.uut.reset_out.connect();
     dev.uut.send.connect();
     dev.uut.sig_in.connect();
     dev.connect_all();
@@ -88,12 +96,13 @@ fn test_vector_synchronizer() {
     });
     sim.add_testbench(move |mut sim: Sim<TestCircuit>| {
         let mut x = sim.init()?;
-        x = sim.watch(|x| x.uut.clock_in.val().0, x)?;
+        reset_sim!(sim, uut.clock_in, uut.reset_in, x);
+        x = sim.watch(|x| x.uut.clock_in.val().clk, x)?;
         for i in 0..150 {
             x.uut.sig_in.next = (i as u32).into();
             x.uut.send.next = true;
-            x = sim.watch(|x| !x.uut.clock_in.val().0, x)?;
-            x = sim.watch(|x| x.uut.clock_in.val().0, x)?;
+            x = sim.watch(|x| !x.uut.clock_in.val().clk, x)?;
+            x = sim.watch(|x| x.uut.clock_in.val().clk, x)?;
             x.uut.send.next = false;
             x = sim.watch(|x| !x.uut.busy.val(), x)?;
         }
@@ -102,12 +111,13 @@ fn test_vector_synchronizer() {
     });
     sim.add_testbench(move |mut sim: Sim<TestCircuit>| {
         let mut x = sim.init()?;
-        x = sim.watch(|x| x.uut.clock_out.val().0, x)?;
+        reset_sim!(sim, uut.clock_out, uut.reset_out, x);
+        x = sim.watch(|x| x.uut.clock_out.val().clk, x)?;
         for i in 0_u32..150_u32 {
             x = sim.watch(|x| x.uut.update.val(), x)?;
             sim_assert!(sim, x.uut.sig_out.val().eq(&i), x);
-            x = sim.watch(|x| !x.uut.clock_out.val().0, x)?;
-            x = sim.watch(|x| x.uut.clock_out.val().0, x)?;
+            x = sim.watch(|x| !x.uut.clock_out.val().clk, x)?;
+            x = sim.watch(|x| x.uut.clock_out.val().clk, x)?;
         }
         sim.done(x)?;
         Ok(())
@@ -122,6 +132,7 @@ fn test_vector_synchronizer() {
 
 #[derive(LogicBlock, Default)]
 struct SynchronousFIFOTest {
+    pub reset: Signal<In, Reset>,
     pub clock: Signal<In, Clock>,
     pub fifo: SynchronousFIFO<Bits<16>, 4, 5, 4>,
 }
@@ -129,7 +140,7 @@ struct SynchronousFIFOTest {
 impl Logic for SynchronousFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.fifo.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, fifo);
     }
 }
 
@@ -137,6 +148,7 @@ impl Logic for SynchronousFIFOTest {
 fn test_sync_fifo_read_behavior_bug() {
     let mut uut = SynchronousFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -147,6 +159,7 @@ fn test_sync_fifo_read_behavior_bug() {
     });
     sim.add_testbench(move |mut sim: Sim<SynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for counter in 0_u32..8 {
             x.fifo.data_in.next = counter.into();
@@ -178,6 +191,7 @@ declare_sync_fifo!(BigFIFO, Bits<8>, 1024, 256);
 
 #[derive(LogicBlock, Default)]
 struct BigFIFOTest {
+    pub reset: Signal<In, Reset>,
     pub clock: Signal<In, Clock>,
     pub fifo: BigFIFO,
 }
@@ -185,7 +199,7 @@ struct BigFIFOTest {
 impl Logic for BigFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.fifo.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, fifo);
     }
 }
 
@@ -193,6 +207,7 @@ impl Logic for BigFIFOTest {
 fn test_almost_empty_is_accurate_in_large_fifo() {
     let mut uut = BigFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -201,6 +216,7 @@ fn test_almost_empty_is_accurate_in_large_fifo() {
     sim.add_clock(5, |x: &mut Box<BigFIFOTest>| x.clock.next = !x.clock.val());
     sim.add_testbench(move |mut sim: Sim<BigFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for counter in 0_u32..1024_u32 {
             x.fifo.data_in.next = counter.into();
@@ -224,6 +240,7 @@ fn test_almost_empty_is_accurate_in_large_fifo() {
 fn test_almost_empty_is_accurate_synchronous_fifo() {
     let mut uut = SynchronousFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -234,6 +251,7 @@ fn test_almost_empty_is_accurate_synchronous_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<SynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for counter in 0_u32..4_u32 {
             x.fifo.data_in.next = counter.into();
@@ -267,6 +285,7 @@ fn test_almost_empty_is_accurate_synchronous_fifo() {
 fn test_fifo_can_be_filled_synchronous_fifo() {
     let mut uut = SynchronousFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -281,6 +300,7 @@ fn test_fifo_can_be_filled_synchronous_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<SynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for sample in &rdata {
             x.fifo.data_in.next = (*sample).into();
@@ -312,6 +332,7 @@ fn test_fifo_can_be_filled_synchronous_fifo() {
 fn test_fifo_works_synchronous_fifo() {
     let mut uut = SynchronousFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -327,6 +348,7 @@ fn test_fifo_works_synchronous_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<SynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for sample in &rdata {
             x = sim.watch(|x| !x.fifo.full.val(), x)?;
@@ -376,7 +398,9 @@ fn test_fifo_works_synchronous_fifo() {
 #[derive(LogicBlock, Default)]
 struct AsynchronousFIFOTest {
     pub read_clock: Signal<In, Clock>,
+    pub read_reset: Signal<In, Reset>,
     pub write_clock: Signal<In, Clock>,
+    pub write_reset: Signal<In, Reset>,
     pub fifo: AsynchronousFIFO<Bits<16>, 4, 5, 4>,
 }
 
@@ -384,14 +408,18 @@ impl Logic for AsynchronousFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
         self.fifo.write_clock.next = self.write_clock.val();
+        self.fifo.write_reset.next = self.write_reset.val();
         self.fifo.read_clock.next = self.read_clock.val();
+        self.fifo.read_reset.next = self.read_reset.val();
     }
 }
 
 #[test]
 fn test_fifo_works_asynchronous_fifo() {
     let mut uut = AsynchronousFIFOTest::default();
+    uut.read_reset.connect();
     uut.read_clock.connect();
+    uut.write_reset.connect();
     uut.write_clock.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
@@ -411,6 +439,7 @@ fn test_fifo_works_asynchronous_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<AsynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, write_clock, write_reset, x);
         wait_clock_true!(sim, write_clock, x);
         for sample in &rdata {
             x = sim.watch(|x| !x.fifo.full.val(), x)?;
@@ -431,6 +460,7 @@ fn test_fifo_works_asynchronous_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<AsynchronousFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, read_clock, read_reset, x);
         wait_clock_true!(sim, read_clock, x);
         for sample in &rdata_read {
             x = sim.watch(|x| !x.fifo.empty.val(), x)?;
@@ -459,7 +489,9 @@ fn test_fifo_works_asynchronous_fifo() {
 
 #[derive(LogicBlock, Default)]
 struct AsyncBigFIFOTest {
+    pub read_reset: Signal<In, Reset>,
     pub read_clock: Signal<In, Clock>,
+    pub write_reset: Signal<In, Reset>,
     pub write_clock: Signal<In, Clock>,
     pub fifo: AsynchronousFIFO<Bits<16>, 10, 11, 256>,
 }
@@ -467,7 +499,9 @@ struct AsyncBigFIFOTest {
 impl Logic for AsyncBigFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
+        self.fifo.write_reset.next = self.write_reset.val();
         self.fifo.write_clock.next = self.write_clock.val();
+        self.fifo.read_reset.next = self.read_reset.val();
         self.fifo.read_clock.next = self.read_clock.val();
     }
 }
@@ -476,7 +510,9 @@ impl Logic for AsyncBigFIFOTest {
 fn test_almost_empty_is_accurate_in_large_async_fifo() {
     let mut uut = AsyncBigFIFOTest::default();
     uut.read_clock.connect();
+    uut.read_reset.connect();
     uut.write_clock.connect();
+    uut.write_reset.connect();
     uut.fifo.read.connect();
     uut.fifo.data_in.connect();
     uut.fifo.write.connect();
@@ -490,6 +526,8 @@ fn test_almost_empty_is_accurate_in_large_async_fifo() {
     });
     sim.add_testbench(move |mut sim: Sim<AsyncBigFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, write_clock, write_reset, x);
+        reset_sim!(sim, read_clock, read_reset, x);
         wait_clock_true!(sim, write_clock, x);
         for counter in 0_u32..1024_u32 {
             x.fifo.data_in.next = counter.into();
@@ -513,6 +551,7 @@ fn test_almost_empty_is_accurate_in_large_async_fifo() {
 #[derive(LogicBlock, Default)]
 struct ReducerFIFOTest {
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     pub wide_fifo: SynchronousFIFO<Bits<16>, 4, 5, 4>,
     pub narrow_fifo: SynchronousFIFO<Bits<8>, 4, 5, 4>,
     pub reducer: FIFOReducer<16, 8, false>,
@@ -521,9 +560,7 @@ struct ReducerFIFOTest {
 impl Logic for ReducerFIFOTest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.wide_fifo.clock.next = self.clock.val();
-        self.narrow_fifo.clock.next = self.clock.val();
-        self.reducer.clock.next = self.clock.val();
+        clock_reset!(self, clock, reset, wide_fifo, narrow_fifo, reducer);
         // Connect the reducer to the wide (upstream) FIFO
         self.reducer.data_in.next = self.wide_fifo.data_out.val();
         self.reducer.empty.next = self.wide_fifo.empty.val();
@@ -539,6 +576,7 @@ impl Logic for ReducerFIFOTest {
 fn test_fifo_reducer_works() {
     let mut uut = ReducerFIFOTest::default();
     uut.clock.connect();
+    uut.reset.connect();
     uut.wide_fifo.write.connect();
     uut.wide_fifo.data_in.connect();
     uut.narrow_fifo.read.connect();
@@ -558,6 +596,7 @@ fn test_fifo_reducer_works() {
     });
     sim.add_testbench(move |mut sim: Sim<ReducerFIFOTest>| {
         let mut x = sim.init()?;
+        reset_sim!(sim, clock, reset, x);
         wait_clock_true!(sim, clock, x);
         for sample in &rdata {
             x = sim.watch(|x| !x.wide_fifo.full.val(), x)?;
