@@ -39,7 +39,7 @@ impl FIFOSDRAMTest {
 #[cfg(test)]
 fn make_test_fifo_controller() -> FIFOSDRAMTest {
     let timings = MemoryTimings::fast_boot_sim(100e6);
-    let mut uut = FIFOSDRAMTest::new(3, timings, OutputBuffer::DelayOne);
+    let mut uut = FIFOSDRAMTest::new(3, timings, OutputBuffer::DelayTwo);
     uut.fifo.write.connect();
     uut.fifo.data_in.connect();
     uut.fifo.read.connect();
@@ -63,6 +63,7 @@ fn test_sdram_works() {
     });
     sim.add_testbench(move |mut sim: Sim<FIFOSDRAMTest>| {
         let mut x = sim.init()?;
+        wait_clock_cycles!(sim, clock, x, 10);
         wait_clock_true!(sim, clock, x);
         for counter in 0_u32..512_u32 {
             x = sim.watch(|x| !x.fifo.full.val(), x)?;
@@ -75,6 +76,7 @@ fn test_sdram_works() {
     });
     sim.add_testbench(move |mut sim: Sim<FIFOSDRAMTest>| {
         let mut x = sim.init()?;
+        wait_clock_cycles!(sim, clock, x, 10);
         wait_clock_true!(sim, clock, x);
         for counter in 0_u32..512_u32 {
             x = sim.watch(|x| !x.fifo.empty.val(), x)?;
